
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.26.7.post1',
    'branch_nick': 'hotfix-1.26.7.post1',
    'revision_id': '8b76a1103240b97da43676f7b8eab8170b1ff5da',
    'revno': 10885
}
